Trait Add
Source pub trait Add {
type Rhs: SqlType;
type Output: SqlType;
}
Represents SQL types which can be added.
The SQL type which can be added to this one
The SQL type of the result of adding Rhs to Self
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
SourceAvailable on crate feature postgres_backend only.
SourceAvailable on crate feature postgres_backend only.
SourceAvailable on crate feature postgres_backend only.
SourceAvailable on crate feature mysql_backend only.