Trait Sub
Source pub trait Sub {
type Rhs: SqlType;
type Output: SqlType;
}
Represents SQL types which can be subtracted.
The SQL type which can be subtracted from this one
The SQL type of the result of subtracting Rhs from Self
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
SourceAvailable on crate feature postgres_backend only.
SourceAvailable on crate feature postgres_backend only.
SourceAvailable on crate feature postgres_backend only.
SourceAvailable on crate feature mysql_backend only.